# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetStorageObjectsResult',
    'AwaitableGetStorageObjectsResult',
    'get_storage_objects',
    'get_storage_objects_output',
]

@pulumi.output_type
class GetStorageObjectsResult:
    """
    A collection of values returned by getStorageObjects.
    """
    def __init__(__self__, id=None, key_marker=None, limit=None, name=None, objects=None, prefix=None, region_name=None, service_name=None, version_id_marker=None, with_versions=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_marker and not isinstance(key_marker, str):
            raise TypeError("Expected argument 'key_marker' to be a str")
        pulumi.set(__self__, "key_marker", key_marker)
        if limit and not isinstance(limit, float):
            raise TypeError("Expected argument 'limit' to be a float")
        pulumi.set(__self__, "limit", limit)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if objects and not isinstance(objects, list):
            raise TypeError("Expected argument 'objects' to be a list")
        pulumi.set(__self__, "objects", objects)
        if prefix and not isinstance(prefix, str):
            raise TypeError("Expected argument 'prefix' to be a str")
        pulumi.set(__self__, "prefix", prefix)
        if region_name and not isinstance(region_name, str):
            raise TypeError("Expected argument 'region_name' to be a str")
        pulumi.set(__self__, "region_name", region_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if version_id_marker and not isinstance(version_id_marker, str):
            raise TypeError("Expected argument 'version_id_marker' to be a str")
        pulumi.set(__self__, "version_id_marker", version_id_marker)
        if with_versions and not isinstance(with_versions, bool):
            raise TypeError("Expected argument 'with_versions' to be a bool")
        pulumi.set(__self__, "with_versions", with_versions)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyMarker")
    def key_marker(self) -> Optional[builtins.str]:
        """
        Key to start with when listing objects
        """
        return pulumi.get(self, "key_marker")

    @property
    @pulumi.getter
    def limit(self) -> Optional[builtins.float]:
        """
        Limit the number of objects returned (1000 maximum, defaults to 1000)
        """
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def objects(self) -> Sequence['outputs.GetStorageObjectsObjectResult']:
        return pulumi.get(self, "objects")

    @property
    @pulumi.getter
    def prefix(self) -> Optional[builtins.str]:
        """
        List objects whose key begins with this prefix
        """
        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> builtins.str:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="versionIdMarker")
    def version_id_marker(self) -> Optional[builtins.str]:
        """
        Version ID to start listing from
        """
        return pulumi.get(self, "version_id_marker")

    @property
    @pulumi.getter(name="withVersions")
    def with_versions(self) -> Optional[builtins.bool]:
        """
        List object versions
        """
        return pulumi.get(self, "with_versions")


class AwaitableGetStorageObjectsResult(GetStorageObjectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStorageObjectsResult(
            id=self.id,
            key_marker=self.key_marker,
            limit=self.limit,
            name=self.name,
            objects=self.objects,
            prefix=self.prefix,
            region_name=self.region_name,
            service_name=self.service_name,
            version_id_marker=self.version_id_marker,
            with_versions=self.with_versions)


def get_storage_objects(key_marker: Optional[builtins.str] = None,
                        limit: Optional[builtins.float] = None,
                        name: Optional[builtins.str] = None,
                        prefix: Optional[builtins.str] = None,
                        region_name: Optional[builtins.str] = None,
                        service_name: Optional[builtins.str] = None,
                        version_id_marker: Optional[builtins.str] = None,
                        with_versions: Optional[builtins.bool] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStorageObjectsResult:
    """
    Get objects of S3™* compatible storage containers. \\* S3 is a trademark filed by Amazon Technologies,Inc. OVHcloud's service is not sponsored by, endorsed by, or otherwise affiliated with Amazon Technologies,Inc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    objects = ovh.CloudProject.get_storage_objects(service_name="<public cloud project ID>",
        region_name="GRA",
        name="<bucket name>")
    ```


    :param builtins.str key_marker: Key to start with when listing objects
    :param builtins.float limit: Limit the number of objects returned (1000 maximum, defaults to 1000)
    :param builtins.str name: Name
    :param builtins.str prefix: List objects whose key begins with this prefix
    :param builtins.str region_name: Region name
    :param builtins.str service_name: Service name
    :param builtins.str version_id_marker: Version ID to start listing from
    :param builtins.bool with_versions: List object versions
    """
    __args__ = dict()
    __args__['keyMarker'] = key_marker
    __args__['limit'] = limit
    __args__['name'] = name
    __args__['prefix'] = prefix
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    __args__['versionIdMarker'] = version_id_marker
    __args__['withVersions'] = with_versions
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getStorageObjects:getStorageObjects', __args__, opts=opts, typ=GetStorageObjectsResult).value

    return AwaitableGetStorageObjectsResult(
        id=pulumi.get(__ret__, 'id'),
        key_marker=pulumi.get(__ret__, 'key_marker'),
        limit=pulumi.get(__ret__, 'limit'),
        name=pulumi.get(__ret__, 'name'),
        objects=pulumi.get(__ret__, 'objects'),
        prefix=pulumi.get(__ret__, 'prefix'),
        region_name=pulumi.get(__ret__, 'region_name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        version_id_marker=pulumi.get(__ret__, 'version_id_marker'),
        with_versions=pulumi.get(__ret__, 'with_versions'))
def get_storage_objects_output(key_marker: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               limit: Optional[pulumi.Input[Optional[builtins.float]]] = None,
                               name: Optional[pulumi.Input[builtins.str]] = None,
                               prefix: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               region_name: Optional[pulumi.Input[builtins.str]] = None,
                               service_name: Optional[pulumi.Input[builtins.str]] = None,
                               version_id_marker: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               with_versions: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStorageObjectsResult]:
    """
    Get objects of S3™* compatible storage containers. \\* S3 is a trademark filed by Amazon Technologies,Inc. OVHcloud's service is not sponsored by, endorsed by, or otherwise affiliated with Amazon Technologies,Inc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    objects = ovh.CloudProject.get_storage_objects(service_name="<public cloud project ID>",
        region_name="GRA",
        name="<bucket name>")
    ```


    :param builtins.str key_marker: Key to start with when listing objects
    :param builtins.float limit: Limit the number of objects returned (1000 maximum, defaults to 1000)
    :param builtins.str name: Name
    :param builtins.str prefix: List objects whose key begins with this prefix
    :param builtins.str region_name: Region name
    :param builtins.str service_name: Service name
    :param builtins.str version_id_marker: Version ID to start listing from
    :param builtins.bool with_versions: List object versions
    """
    __args__ = dict()
    __args__['keyMarker'] = key_marker
    __args__['limit'] = limit
    __args__['name'] = name
    __args__['prefix'] = prefix
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    __args__['versionIdMarker'] = version_id_marker
    __args__['withVersions'] = with_versions
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getStorageObjects:getStorageObjects', __args__, opts=opts, typ=GetStorageObjectsResult)
    return __ret__.apply(lambda __response__: GetStorageObjectsResult(
        id=pulumi.get(__response__, 'id'),
        key_marker=pulumi.get(__response__, 'key_marker'),
        limit=pulumi.get(__response__, 'limit'),
        name=pulumi.get(__response__, 'name'),
        objects=pulumi.get(__response__, 'objects'),
        prefix=pulumi.get(__response__, 'prefix'),
        region_name=pulumi.get(__response__, 'region_name'),
        service_name=pulumi.get(__response__, 'service_name'),
        version_id_marker=pulumi.get(__response__, 'version_id_marker'),
        with_versions=pulumi.get(__response__, 'with_versions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IdentityUserArgs', 'IdentityUser']

@pulumi.input_type
class IdentityUserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[builtins.str],
                 login: pulumi.Input[builtins.str],
                 password: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a IdentityUser resource.
        :param pulumi.Input[builtins.str] email: User's email.
        :param pulumi.Input[builtins.str] login: User's login suffix.
        :param pulumi.Input[builtins.str] password: User's password.
        :param pulumi.Input[builtins.str] description: User description.
        :param pulumi.Input[builtins.str] group: User's group.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "login", login)
        pulumi.set(__self__, "password", password)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group is not None:
            pulumi.set(__self__, "group", group)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[builtins.str]:
        """
        User's email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def login(self) -> pulumi.Input[builtins.str]:
        """
        User's login suffix.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[builtins.str]:
        """
        User's password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User's group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group", value)


@pulumi.input_type
class _IdentityUserState:
    def __init__(__self__, *,
                 user_urn: Optional[pulumi.Input[builtins.str]] = None,
                 creation: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None,
                 last_update: Optional[pulumi.Input[builtins.str]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_last_update: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering IdentityUser resources.
        :param pulumi.Input[builtins.str] user_urn: URN of the user, used when writing IAM policies
        :param pulumi.Input[builtins.str] creation: Creation date of this user.
        :param pulumi.Input[builtins.str] description: User description.
        :param pulumi.Input[builtins.str] email: User's email.
        :param pulumi.Input[builtins.str] group: User's group.
        :param pulumi.Input[builtins.str] last_update: Last update of this user.
        :param pulumi.Input[builtins.str] login: User's login suffix.
        :param pulumi.Input[builtins.str] password: User's password.
        :param pulumi.Input[builtins.str] password_last_update: When the user changed his password for the last time.
        :param pulumi.Input[builtins.str] status: Current user's status.
        """
        if user_urn is not None:
            pulumi.set(__self__, "user_urn", user_urn)
        if creation is not None:
            pulumi.set(__self__, "creation", creation)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_last_update is not None:
            pulumi.set(__self__, "password_last_update", password_last_update)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="UserURN")
    def user_urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the user, used when writing IAM policies
        """
        return pulumi.get(self, "user_urn")

    @user_urn.setter
    def user_urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_urn", value)

    @property
    @pulumi.getter
    def creation(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of this user.
        """
        return pulumi.get(self, "creation")

    @creation.setter
    def creation(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User's email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User's group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last update of this user.
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_update", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User's login suffix.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User's password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordLastUpdate")
    def password_last_update(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When the user changed his password for the last time.
        """
        return pulumi.get(self, "password_last_update")

    @password_last_update.setter
    def password_last_update(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_last_update", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current user's status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:Me/identityUser:IdentityUser")
class IdentityUser(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an identity user.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_user = ovh.me.IdentityUser("my_user",
            description="Some custom description",
            email="my_login@example.com",
            group="DEFAULT",
            login="my_login",
            password="super-s3cr3t!password")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: User description.
        :param pulumi.Input[builtins.str] email: User's email.
        :param pulumi.Input[builtins.str] group: User's group.
        :param pulumi.Input[builtins.str] login: User's login suffix.
        :param pulumi.Input[builtins.str] password: User's password.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IdentityUserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an identity user.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_user = ovh.me.IdentityUser("my_user",
            description="Some custom description",
            email="my_login@example.com",
            group="DEFAULT",
            login="my_login",
            password="super-s3cr3t!password")
        ```

        :param str resource_name: The name of the resource.
        :param IdentityUserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IdentityUserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 group: Optional[pulumi.Input[builtins.str]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IdentityUserArgs.__new__(IdentityUserArgs)

            __props__.__dict__["description"] = description
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["group"] = group
            if login is None and not opts.urn:
                raise TypeError("Missing required property 'login'")
            __props__.__dict__["login"] = login
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["user_urn"] = None
            __props__.__dict__["creation"] = None
            __props__.__dict__["last_update"] = None
            __props__.__dict__["password_last_update"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IdentityUser, __self__).__init__(
            'ovh:Me/identityUser:IdentityUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            user_urn: Optional[pulumi.Input[builtins.str]] = None,
            creation: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            email: Optional[pulumi.Input[builtins.str]] = None,
            group: Optional[pulumi.Input[builtins.str]] = None,
            last_update: Optional[pulumi.Input[builtins.str]] = None,
            login: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            password_last_update: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'IdentityUser':
        """
        Get an existing IdentityUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] user_urn: URN of the user, used when writing IAM policies
        :param pulumi.Input[builtins.str] creation: Creation date of this user.
        :param pulumi.Input[builtins.str] description: User description.
        :param pulumi.Input[builtins.str] email: User's email.
        :param pulumi.Input[builtins.str] group: User's group.
        :param pulumi.Input[builtins.str] last_update: Last update of this user.
        :param pulumi.Input[builtins.str] login: User's login suffix.
        :param pulumi.Input[builtins.str] password: User's password.
        :param pulumi.Input[builtins.str] password_last_update: When the user changed his password for the last time.
        :param pulumi.Input[builtins.str] status: Current user's status.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IdentityUserState.__new__(_IdentityUserState)

        __props__.__dict__["user_urn"] = user_urn
        __props__.__dict__["creation"] = creation
        __props__.__dict__["description"] = description
        __props__.__dict__["email"] = email
        __props__.__dict__["group"] = group
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["login"] = login
        __props__.__dict__["password"] = password
        __props__.__dict__["password_last_update"] = password_last_update
        __props__.__dict__["status"] = status
        return IdentityUser(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="UserURN")
    def user_urn(self) -> pulumi.Output[builtins.str]:
        """
        URN of the user, used when writing IAM policies
        """
        return pulumi.get(self, "user_urn")

    @property
    @pulumi.getter
    def creation(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of this user.
        """
        return pulumi.get(self, "creation")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        User description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[builtins.str]:
        """
        User's email.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def group(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        User's group.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[builtins.str]:
        """
        Last update of this user.
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter
    def login(self) -> pulumi.Output[builtins.str]:
        """
        User's login suffix.
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        User's password.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordLastUpdate")
    def password_last_update(self) -> pulumi.Output[builtins.str]:
        """
        When the user changed his password for the last time.
        """
        return pulumi.get(self, "password_last_update")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Current user's status.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .alerting import *
from .container_registry import *
from .container_registry_ip_restrictions_management import *
from .container_registry_ip_restrictions_registry import *
from .container_registry_oidc import *
from .container_registry_user import *
from .database import *
from .failover_ip_attach import *
from .gateway import *
from .gateway_interface import *
from .get_capabilities_container_filter import *
from .get_capabilities_container_registry import *
from .get_container_registries import *
from .get_container_registry import *
from .get_container_registry_ip_restrictions_management import *
from .get_container_registry_ip_restrictions_registry import *
from .get_container_registry_oidc import *
from .get_container_registry_users import *
from .get_failover_ip_attach import *
from .get_flavors import *
from .get_floating_ips import *
from .get_gateway_interface import *
from .get_image import *
from .get_images import *
from .get_instance import *
from .get_instances import *
from .get_kube import *
from .get_kube_ip_restrictions import *
from .get_kube_node_pool import *
from .get_kube_node_pool_nodes import *
from .get_kube_nodes import *
from .get_kube_oidc import *
from .get_load_balancer import *
from .get_load_balancer_flavors import *
from .get_load_balancers import *
from .get_m3db_namespace import *
from .get_m3db_namespaces import *
from .get_m3db_user import *
from .get_mongo_db_prometheus import *
from .get_mongo_db_user import *
from .get_network_private import *
from .get_network_private_subnets import *
from .get_network_privates import *
from .get_open_search_pattern import *
from .get_open_search_patterns import *
from .get_open_search_user import *
from .get_prometheus import *
from .get_rancher import *
from .get_rancher_plan import *
from .get_rancher_version import *
from .get_redis_user import *
from .get_region import *
from .get_region_load_balancer_log_subscription import *
from .get_region_load_balancer_log_subscriptions import *
from .get_regions import *
from .get_storage import *
from .get_storage_object import *
from .get_storage_objects import *
from .get_storages import *
from .get_user import *
from .get_user_s3_credential import *
from .get_user_s3_credentials import *
from .get_user_s3_policy import *
from .get_users import *
from .get_v_rack import *
from .get_volume import *
from .get_volumes import *
from .instance import *
from .instance_snapshot import *
from .kube import *
from .kube_ip_restrictions import *
from .kube_node_pool import *
from .kube_oidc import *
from .load_balancer import *
from .network_private import *
from .network_private_subnet import *
from .network_private_subnet_v2 import *
from .project import *
from .rancher import *
from .region_load_balancer_log_subscription import *
from .region_network import *
from .region_storage_presign import *
from .s3_credential import *
from .s3_policy import *
from .storage import *
from .user import *
from .volume import *
from .volume_backup import *
from .workflow_backup import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'LogsInputConfiguration',
    'LogsInputConfigurationFlowgger',
    'LogsInputConfigurationLogstash',
]

@pulumi.output_type
class LogsInputConfiguration(dict):
    def __init__(__self__, *,
                 flowgger: Optional['outputs.LogsInputConfigurationFlowgger'] = None,
                 logstash: Optional['outputs.LogsInputConfigurationLogstash'] = None):
        """
        :param 'LogsInputConfigurationFlowggerArgs' flowgger: Flowgger configuration
        :param 'LogsInputConfigurationLogstashArgs' logstash: Logstash configuration
        """
        if flowgger is not None:
            pulumi.set(__self__, "flowgger", flowgger)
        if logstash is not None:
            pulumi.set(__self__, "logstash", logstash)

    @property
    @pulumi.getter
    def flowgger(self) -> Optional['outputs.LogsInputConfigurationFlowgger']:
        """
        Flowgger configuration
        """
        return pulumi.get(self, "flowgger")

    @property
    @pulumi.getter
    def logstash(self) -> Optional['outputs.LogsInputConfigurationLogstash']:
        """
        Logstash configuration
        """
        return pulumi.get(self, "logstash")


@pulumi.output_type
class LogsInputConfigurationFlowgger(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "logFormat":
            suggest = "log_format"
        elif key == "logFraming":
            suggest = "log_framing"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LogsInputConfigurationFlowgger. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LogsInputConfigurationFlowgger.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LogsInputConfigurationFlowgger.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 log_format: builtins.str,
                 log_framing: builtins.str):
        """
        :param builtins.str log_format: Type of format to decode. One of "RFC5424", "LTSV", "GELF", "CAPNP"
        :param builtins.str log_framing: Indicates how messages are delimited. One of "LINE", "NUL", "SYSLEN", "CAPNP"
        """
        pulumi.set(__self__, "log_format", log_format)
        pulumi.set(__self__, "log_framing", log_framing)

    @property
    @pulumi.getter(name="logFormat")
    def log_format(self) -> builtins.str:
        """
        Type of format to decode. One of "RFC5424", "LTSV", "GELF", "CAPNP"
        """
        return pulumi.get(self, "log_format")

    @property
    @pulumi.getter(name="logFraming")
    def log_framing(self) -> builtins.str:
        """
        Indicates how messages are delimited. One of "LINE", "NUL", "SYSLEN", "CAPNP"
        """
        return pulumi.get(self, "log_framing")


@pulumi.output_type
class LogsInputConfigurationLogstash(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "inputSection":
            suggest = "input_section"
        elif key == "filterSection":
            suggest = "filter_section"
        elif key == "patternSection":
            suggest = "pattern_section"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LogsInputConfigurationLogstash. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LogsInputConfigurationLogstash.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LogsInputConfigurationLogstash.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 input_section: builtins.str,
                 filter_section: Optional[builtins.str] = None,
                 pattern_section: Optional[builtins.str] = None):
        """
        :param builtins.str input_section: The filter section of logstash.conf
        :param builtins.str filter_section: The filter section of logstash.conf
        :param builtins.str pattern_section: The list of customs Grok patterns
        """
        pulumi.set(__self__, "input_section", input_section)
        if filter_section is not None:
            pulumi.set(__self__, "filter_section", filter_section)
        if pattern_section is not None:
            pulumi.set(__self__, "pattern_section", pattern_section)

    @property
    @pulumi.getter(name="inputSection")
    def input_section(self) -> builtins.str:
        """
        The filter section of logstash.conf
        """
        return pulumi.get(self, "input_section")

    @property
    @pulumi.getter(name="filterSection")
    def filter_section(self) -> Optional[builtins.str]:
        """
        The filter section of logstash.conf
        """
        return pulumi.get(self, "filter_section")

    @property
    @pulumi.getter(name="patternSection")
    def pattern_section(self) -> Optional[builtins.str]:
        """
        The list of customs Grok patterns
        """
        return pulumi.get(self, "pattern_section")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PermissionsGroupArgs', 'PermissionsGroup']

@pulumi.input_type
class PermissionsGroupArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[builtins.str],
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a PermissionsGroup resource.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: Set of actions allowed by the permissions group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: Set of actions that will be denied no matter what permissions group exists.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: Set of actions that will be subtracted from the `allow` list.
        :param pulumi.Input[builtins.str] name: Name of the permissions group.
        :param pulumi.Input[builtins.str] updated_at: Date of the last update of this group.
        """
        pulumi.set(__self__, "description", description)
        if allows is not None:
            pulumi.set(__self__, "allows", allows)
        if denies is not None:
            pulumi.set(__self__, "denies", denies)
        if excepts is not None:
            pulumi.set(__self__, "excepts", excepts)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[builtins.str]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of actions allowed by the permissions group.
        """
        return pulumi.get(self, "allows")

    @allows.setter
    def allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allows", value)

    @property
    @pulumi.getter
    def denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of actions that will be denied no matter what permissions group exists.
        """
        return pulumi.get(self, "denies")

    @denies.setter
    def denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "denies", value)

    @property
    @pulumi.getter
    def excepts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of actions that will be subtracted from the `allow` list.
        """
        return pulumi.get(self, "excepts")

    @excepts.setter
    def excepts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "excepts", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the permissions group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.input_type
class _PermissionsGroupState:
    def __init__(__self__, *,
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 owner: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 urn: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PermissionsGroup resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: Set of actions allowed by the permissions group.
        :param pulumi.Input[builtins.str] created_at: Creation date of this group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: Set of actions that will be denied no matter what permissions group exists.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: Set of actions that will be subtracted from the `allow` list.
        :param pulumi.Input[builtins.str] name: Name of the permissions group.
        :param pulumi.Input[builtins.str] owner: Owner of the permissions group.
        :param pulumi.Input[builtins.str] updated_at: Date of the last update of this group.
        :param pulumi.Input[builtins.str] urn: URN of the permissions group.
        """
        if allows is not None:
            pulumi.set(__self__, "allows", allows)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if denies is not None:
            pulumi.set(__self__, "denies", denies)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if excepts is not None:
            pulumi.set(__self__, "excepts", excepts)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if urn is not None:
            pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter
    def allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of actions allowed by the permissions group.
        """
        return pulumi.get(self, "allows")

    @allows.setter
    def allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allows", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of actions that will be denied no matter what permissions group exists.
        """
        return pulumi.get(self, "denies")

    @denies.setter
    def denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "denies", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def excepts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Set of actions that will be subtracted from the `allow` list.
        """
        return pulumi.get(self, "excepts")

    @excepts.setter
    def excepts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "excepts", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the permissions group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Owner of the permissions group.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the permissions group.
        """
        return pulumi.get(self, "urn")

    @urn.setter
    def urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urn", value)


@pulumi.type_token("ovh:Iam/permissionsGroup:PermissionsGroup")
class PermissionsGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Create am IAM permissions group.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: Set of actions allowed by the permissions group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: Set of actions that will be denied no matter what permissions group exists.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: Set of actions that will be subtracted from the `allow` list.
        :param pulumi.Input[builtins.str] name: Name of the permissions group.
        :param pulumi.Input[builtins.str] updated_at: Date of the last update of this group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PermissionsGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create am IAM permissions group.

        :param str resource_name: The name of the resource.
        :param PermissionsGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PermissionsGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PermissionsGroupArgs.__new__(PermissionsGroupArgs)

            __props__.__dict__["allows"] = allows
            __props__.__dict__["denies"] = denies
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["excepts"] = excepts
            __props__.__dict__["name"] = name
            __props__.__dict__["updated_at"] = updated_at
            __props__.__dict__["created_at"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["urn"] = None
        super(PermissionsGroup, __self__).__init__(
            'ovh:Iam/permissionsGroup:PermissionsGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allows: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            denies: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            excepts: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            owner: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            urn: Optional[pulumi.Input[builtins.str]] = None) -> 'PermissionsGroup':
        """
        Get an existing PermissionsGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allows: Set of actions allowed by the permissions group.
        :param pulumi.Input[builtins.str] created_at: Creation date of this group.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] denies: Set of actions that will be denied no matter what permissions group exists.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] excepts: Set of actions that will be subtracted from the `allow` list.
        :param pulumi.Input[builtins.str] name: Name of the permissions group.
        :param pulumi.Input[builtins.str] owner: Owner of the permissions group.
        :param pulumi.Input[builtins.str] updated_at: Date of the last update of this group.
        :param pulumi.Input[builtins.str] urn: URN of the permissions group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PermissionsGroupState.__new__(_PermissionsGroupState)

        __props__.__dict__["allows"] = allows
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["denies"] = denies
        __props__.__dict__["description"] = description
        __props__.__dict__["excepts"] = excepts
        __props__.__dict__["name"] = name
        __props__.__dict__["owner"] = owner
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["urn"] = urn
        return PermissionsGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def allows(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Set of actions allowed by the permissions group.
        """
        return pulumi.get(self, "allows")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def denies(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Set of actions that will be denied no matter what permissions group exists.
        """
        return pulumi.get(self, "denies")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def excepts(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Set of actions that will be subtracted from the `allow` list.
        """
        return pulumi.get(self, "excepts")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the permissions group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[builtins.str]:
        """
        Owner of the permissions group.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def urn(self) -> pulumi.Output[builtins.str]:
        """
        URN of the permissions group.
        """
        return pulumi.get(self, "urn")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetStorageResult',
    'AwaitableGetStorageResult',
    'get_storage',
    'get_storage_output',
]

@pulumi.output_type
class GetStorageResult:
    """
    A collection of values returned by getStorage.
    """
    def __init__(__self__, created_at=None, encryption=None, id=None, limit=None, marker=None, name=None, objects=None, objects_count=None, objects_size=None, owner_id=None, prefix=None, region=None, region_name=None, replication=None, service_name=None, tags=None, versioning=None, virtual_host=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if encryption and not isinstance(encryption, dict):
            raise TypeError("Expected argument 'encryption' to be a dict")
        pulumi.set(__self__, "encryption", encryption)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit and not isinstance(limit, float):
            raise TypeError("Expected argument 'limit' to be a float")
        pulumi.set(__self__, "limit", limit)
        if marker and not isinstance(marker, str):
            raise TypeError("Expected argument 'marker' to be a str")
        pulumi.set(__self__, "marker", marker)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if objects and not isinstance(objects, list):
            raise TypeError("Expected argument 'objects' to be a list")
        pulumi.set(__self__, "objects", objects)
        if objects_count and not isinstance(objects_count, float):
            raise TypeError("Expected argument 'objects_count' to be a float")
        pulumi.set(__self__, "objects_count", objects_count)
        if objects_size and not isinstance(objects_size, float):
            raise TypeError("Expected argument 'objects_size' to be a float")
        pulumi.set(__self__, "objects_size", objects_size)
        if owner_id and not isinstance(owner_id, float):
            raise TypeError("Expected argument 'owner_id' to be a float")
        pulumi.set(__self__, "owner_id", owner_id)
        if prefix and not isinstance(prefix, str):
            raise TypeError("Expected argument 'prefix' to be a str")
        pulumi.set(__self__, "prefix", prefix)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if region_name and not isinstance(region_name, str):
            raise TypeError("Expected argument 'region_name' to be a str")
        pulumi.set(__self__, "region_name", region_name)
        if replication and not isinstance(replication, dict):
            raise TypeError("Expected argument 'replication' to be a dict")
        pulumi.set(__self__, "replication", replication)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if versioning and not isinstance(versioning, dict):
            raise TypeError("Expected argument 'versioning' to be a dict")
        pulumi.set(__self__, "versioning", versioning)
        if virtual_host and not isinstance(virtual_host, str):
            raise TypeError("Expected argument 'virtual_host' to be a str")
        pulumi.set(__self__, "virtual_host", virtual_host)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        The date and timestamp when the resource was created
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def encryption(self) -> 'outputs.GetStorageEncryptionResult':
        """
        Encryption configuration
        """
        return pulumi.get(self, "encryption")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def limit(self) -> builtins.float:
        """
        Limit the number of objects returned (1000 maximum, defaults to 1000)
        """
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter
    def marker(self) -> builtins.str:
        """
        Key to start with when listing objects
        """
        return pulumi.get(self, "marker")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def objects(self) -> Sequence['outputs.GetStorageObjectResult']:
        """
        Container objects
        """
        return pulumi.get(self, "objects")

    @property
    @pulumi.getter(name="objectsCount")
    def objects_count(self) -> builtins.float:
        """
        Container total objects count
        """
        return pulumi.get(self, "objects_count")

    @property
    @pulumi.getter(name="objectsSize")
    def objects_size(self) -> builtins.float:
        """
        Container total objects size (bytes)
        """
        return pulumi.get(self, "objects_size")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> builtins.float:
        """
        Container owner user ID
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter
    def prefix(self) -> builtins.str:
        """
        List objects whose key begins with this prefix
        """
        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Container region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> builtins.str:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter
    def replication(self) -> 'outputs.GetStorageReplicationResult':
        """
        Replication configuration
        """
        return pulumi.get(self, "replication")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Container tags
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def versioning(self) -> 'outputs.GetStorageVersioningResult':
        """
        Versioning configuration
        """
        return pulumi.get(self, "versioning")

    @property
    @pulumi.getter(name="virtualHost")
    def virtual_host(self) -> builtins.str:
        """
        Container virtual host
        """
        return pulumi.get(self, "virtual_host")


class AwaitableGetStorageResult(GetStorageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStorageResult(
            created_at=self.created_at,
            encryption=self.encryption,
            id=self.id,
            limit=self.limit,
            marker=self.marker,
            name=self.name,
            objects=self.objects,
            objects_count=self.objects_count,
            objects_size=self.objects_size,
            owner_id=self.owner_id,
            prefix=self.prefix,
            region=self.region,
            region_name=self.region_name,
            replication=self.replication,
            service_name=self.service_name,
            tags=self.tags,
            versioning=self.versioning,
            virtual_host=self.virtual_host)


def get_storage(limit: Optional[builtins.float] = None,
                marker: Optional[builtins.str] = None,
                name: Optional[builtins.str] = None,
                prefix: Optional[builtins.str] = None,
                region_name: Optional[builtins.str] = None,
                service_name: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStorageResult:
    """
    Get S3™* compatible storage container. \\* S3 is a trademark filed by Amazon Technologies,Inc. OVHcloud's service is not sponsored by, endorsed by, or otherwise affiliated with Amazon Technologies,Inc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    storage = ovh.CloudProject.get_storage(service_name="<public cloud project ID>",
        region_name="GRA",
        name="my-storage-name")
    ```


    :param builtins.float limit: Limit the number of objects returned (1000 maximum, defaults to 1000)
    :param builtins.str marker: Key to start with when listing objects
    :param builtins.str name: Name
    :param builtins.str prefix: List objects whose key begins with this prefix
    :param builtins.str region_name: Region name
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['marker'] = marker
    __args__['name'] = name
    __args__['prefix'] = prefix
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getStorage:getStorage', __args__, opts=opts, typ=GetStorageResult).value

    return AwaitableGetStorageResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        encryption=pulumi.get(__ret__, 'encryption'),
        id=pulumi.get(__ret__, 'id'),
        limit=pulumi.get(__ret__, 'limit'),
        marker=pulumi.get(__ret__, 'marker'),
        name=pulumi.get(__ret__, 'name'),
        objects=pulumi.get(__ret__, 'objects'),
        objects_count=pulumi.get(__ret__, 'objects_count'),
        objects_size=pulumi.get(__ret__, 'objects_size'),
        owner_id=pulumi.get(__ret__, 'owner_id'),
        prefix=pulumi.get(__ret__, 'prefix'),
        region=pulumi.get(__ret__, 'region'),
        region_name=pulumi.get(__ret__, 'region_name'),
        replication=pulumi.get(__ret__, 'replication'),
        service_name=pulumi.get(__ret__, 'service_name'),
        tags=pulumi.get(__ret__, 'tags'),
        versioning=pulumi.get(__ret__, 'versioning'),
        virtual_host=pulumi.get(__ret__, 'virtual_host'))
def get_storage_output(limit: Optional[pulumi.Input[Optional[builtins.float]]] = None,
                       marker: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                       name: Optional[pulumi.Input[builtins.str]] = None,
                       prefix: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                       region_name: Optional[pulumi.Input[builtins.str]] = None,
                       service_name: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStorageResult]:
    """
    Get S3™* compatible storage container. \\* S3 is a trademark filed by Amazon Technologies,Inc. OVHcloud's service is not sponsored by, endorsed by, or otherwise affiliated with Amazon Technologies,Inc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    storage = ovh.CloudProject.get_storage(service_name="<public cloud project ID>",
        region_name="GRA",
        name="my-storage-name")
    ```


    :param builtins.float limit: Limit the number of objects returned (1000 maximum, defaults to 1000)
    :param builtins.str marker: Key to start with when listing objects
    :param builtins.str name: Name
    :param builtins.str prefix: List objects whose key begins with this prefix
    :param builtins.str region_name: Region name
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['marker'] = marker
    __args__['name'] = name
    __args__['prefix'] = prefix
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getStorage:getStorage', __args__, opts=opts, typ=GetStorageResult)
    return __ret__.apply(lambda __response__: GetStorageResult(
        created_at=pulumi.get(__response__, 'created_at'),
        encryption=pulumi.get(__response__, 'encryption'),
        id=pulumi.get(__response__, 'id'),
        limit=pulumi.get(__response__, 'limit'),
        marker=pulumi.get(__response__, 'marker'),
        name=pulumi.get(__response__, 'name'),
        objects=pulumi.get(__response__, 'objects'),
        objects_count=pulumi.get(__response__, 'objects_count'),
        objects_size=pulumi.get(__response__, 'objects_size'),
        owner_id=pulumi.get(__response__, 'owner_id'),
        prefix=pulumi.get(__response__, 'prefix'),
        region=pulumi.get(__response__, 'region'),
        region_name=pulumi.get(__response__, 'region_name'),
        replication=pulumi.get(__response__, 'replication'),
        service_name=pulumi.get(__response__, 'service_name'),
        tags=pulumi.get(__response__, 'tags'),
        versioning=pulumi.get(__response__, 'versioning'),
        virtual_host=pulumi.get(__response__, 'virtual_host')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetCloudProjectFlavorResult',
    'AwaitableGetCloudProjectFlavorResult',
    'get_cloud_project_flavor',
    'get_cloud_project_flavor_output',
]

@pulumi.output_type
class GetCloudProjectFlavorResult:
    """
    A collection of values returned by getCloudProjectFlavor.
    """
    def __init__(__self__, available=None, capabilities=None, disk=None, id=None, inbound_bandwidth=None, name=None, os_type=None, outbound_bandwidth=None, plan_codes=None, quota=None, ram=None, region=None, service_name=None, type=None, vcpus=None):
        if available and not isinstance(available, bool):
            raise TypeError("Expected argument 'available' to be a bool")
        pulumi.set(__self__, "available", available)
        if capabilities and not isinstance(capabilities, list):
            raise TypeError("Expected argument 'capabilities' to be a list")
        pulumi.set(__self__, "capabilities", capabilities)
        if disk and not isinstance(disk, float):
            raise TypeError("Expected argument 'disk' to be a float")
        pulumi.set(__self__, "disk", disk)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inbound_bandwidth and not isinstance(inbound_bandwidth, float):
            raise TypeError("Expected argument 'inbound_bandwidth' to be a float")
        pulumi.set(__self__, "inbound_bandwidth", inbound_bandwidth)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if os_type and not isinstance(os_type, str):
            raise TypeError("Expected argument 'os_type' to be a str")
        pulumi.set(__self__, "os_type", os_type)
        if outbound_bandwidth and not isinstance(outbound_bandwidth, float):
            raise TypeError("Expected argument 'outbound_bandwidth' to be a float")
        pulumi.set(__self__, "outbound_bandwidth", outbound_bandwidth)
        if plan_codes and not isinstance(plan_codes, dict):
            raise TypeError("Expected argument 'plan_codes' to be a dict")
        pulumi.set(__self__, "plan_codes", plan_codes)
        if quota and not isinstance(quota, float):
            raise TypeError("Expected argument 'quota' to be a float")
        pulumi.set(__self__, "quota", quota)
        if ram and not isinstance(ram, float):
            raise TypeError("Expected argument 'ram' to be a float")
        pulumi.set(__self__, "ram", ram)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if vcpus and not isinstance(vcpus, float):
            raise TypeError("Expected argument 'vcpus' to be a float")
        pulumi.set(__self__, "vcpus", vcpus)

    @property
    @pulumi.getter
    def available(self) -> builtins.bool:
        """
        Available in stock
        """
        return pulumi.get(self, "available")

    @property
    @pulumi.getter
    def capabilities(self) -> Sequence['outputs.GetCloudProjectFlavorCapabilityResult']:
        """
        Capabilities of the flavor
        """
        return pulumi.get(self, "capabilities")

    @property
    @pulumi.getter
    def disk(self) -> builtins.float:
        """
        Number of disks
        """
        return pulumi.get(self, "disk")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Flavor id
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inboundBandwidth")
    def inbound_bandwidth(self) -> builtins.float:
        """
        Max capacity of inbound traffic in Mbit/s
        """
        return pulumi.get(self, "inbound_bandwidth")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Flavor name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="osType")
    def os_type(self) -> builtins.str:
        """
        OS to install on
        """
        return pulumi.get(self, "os_type")

    @property
    @pulumi.getter(name="outboundBandwidth")
    def outbound_bandwidth(self) -> builtins.float:
        """
        Max capacity of outbound traffic in Mbit/s
        """
        return pulumi.get(self, "outbound_bandwidth")

    @property
    @pulumi.getter(name="planCodes")
    def plan_codes(self) -> 'outputs.GetCloudProjectFlavorPlanCodesResult':
        """
        Plan codes to order instances
        """
        return pulumi.get(self, "plan_codes")

    @property
    @pulumi.getter
    def quota(self) -> builtins.float:
        """
        Number instance you can spawn with your actual quota
        """
        return pulumi.get(self, "quota")

    @property
    @pulumi.getter
    def ram(self) -> builtins.float:
        """
        Ram quantity (Gio)
        """
        return pulumi.get(self, "ram")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Flavor region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Flavor type
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def vcpus(self) -> builtins.float:
        """
        Number of VCPUs
        """
        return pulumi.get(self, "vcpus")


class AwaitableGetCloudProjectFlavorResult(GetCloudProjectFlavorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudProjectFlavorResult(
            available=self.available,
            capabilities=self.capabilities,
            disk=self.disk,
            id=self.id,
            inbound_bandwidth=self.inbound_bandwidth,
            name=self.name,
            os_type=self.os_type,
            outbound_bandwidth=self.outbound_bandwidth,
            plan_codes=self.plan_codes,
            quota=self.quota,
            ram=self.ram,
            region=self.region,
            service_name=self.service_name,
            type=self.type,
            vcpus=self.vcpus)


def get_cloud_project_flavor(id: Optional[builtins.str] = None,
                             service_name: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudProjectFlavorResult:
    """
    Retrieves the given flavor in a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    flavor = ovh.get_cloud_project_flavor(service_name="YYYY",
        id="XXXX")
    ```


    :param builtins.str id: Flavor id
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getCloudProjectFlavor:getCloudProjectFlavor', __args__, opts=opts, typ=GetCloudProjectFlavorResult).value

    return AwaitableGetCloudProjectFlavorResult(
        available=pulumi.get(__ret__, 'available'),
        capabilities=pulumi.get(__ret__, 'capabilities'),
        disk=pulumi.get(__ret__, 'disk'),
        id=pulumi.get(__ret__, 'id'),
        inbound_bandwidth=pulumi.get(__ret__, 'inbound_bandwidth'),
        name=pulumi.get(__ret__, 'name'),
        os_type=pulumi.get(__ret__, 'os_type'),
        outbound_bandwidth=pulumi.get(__ret__, 'outbound_bandwidth'),
        plan_codes=pulumi.get(__ret__, 'plan_codes'),
        quota=pulumi.get(__ret__, 'quota'),
        ram=pulumi.get(__ret__, 'ram'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        type=pulumi.get(__ret__, 'type'),
        vcpus=pulumi.get(__ret__, 'vcpus'))
def get_cloud_project_flavor_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                    service_name: Optional[pulumi.Input[builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudProjectFlavorResult]:
    """
    Retrieves the given flavor in a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    flavor = ovh.get_cloud_project_flavor(service_name="YYYY",
        id="XXXX")
    ```


    :param builtins.str id: Flavor id
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getCloudProjectFlavor:getCloudProjectFlavor', __args__, opts=opts, typ=GetCloudProjectFlavorResult)
    return __ret__.apply(lambda __response__: GetCloudProjectFlavorResult(
        available=pulumi.get(__response__, 'available'),
        capabilities=pulumi.get(__response__, 'capabilities'),
        disk=pulumi.get(__response__, 'disk'),
        id=pulumi.get(__response__, 'id'),
        inbound_bandwidth=pulumi.get(__response__, 'inbound_bandwidth'),
        name=pulumi.get(__response__, 'name'),
        os_type=pulumi.get(__response__, 'os_type'),
        outbound_bandwidth=pulumi.get(__response__, 'outbound_bandwidth'),
        plan_codes=pulumi.get(__response__, 'plan_codes'),
        quota=pulumi.get(__response__, 'quota'),
        ram=pulumi.get(__response__, 'ram'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        type=pulumi.get(__response__, 'type'),
        vcpus=pulumi.get(__response__, 'vcpus')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DatabaseInstanceArgs', 'DatabaseInstance']

@pulumi.input_type
class DatabaseInstanceArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 engine: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DatabaseInstance resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        :param pulumi.Input[builtins.str] name: Name of the database.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "engine", engine)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Input[builtins.str]:
        """
        The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the database.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _DatabaseInstanceState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 default: Optional[pulumi.Input[builtins.bool]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseInstance resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.bool] default: Defines if the database has been created by default.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        :param pulumi.Input[builtins.str] name: Name of the database.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines if the database has been created by default.
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the database.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:CloudProjectDatabase/databaseInstance:DatabaseInstance")
class DatabaseInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a database for a database cluster associated with a public cloud project.

        With this resource you can create a database for the following database engine:

        * `mysql`
        * `postgresql`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        db = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="YYYY",
            id="ZZZZ")
        database = ovh.cloud_project_database.DatabaseInstance("database",
            service_name=db.service_name,
            engine=db.engine,
            cluster_id=db.id,
            name="mydatabase")
        ```

        ## Import

        OVHcloud Managed database clusters databases can be imported using the `service_name`, `engine`, `cluster_id` and `id` of the database, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/databaseInstance:DatabaseInstance my_database service_name/engine/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        :param pulumi.Input[builtins.str] name: Name of the database.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a database for a database cluster associated with a public cloud project.

        With this resource you can create a database for the following database engine:

        * `mysql`
        * `postgresql`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        db = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="YYYY",
            id="ZZZZ")
        database = ovh.cloud_project_database.DatabaseInstance("database",
            service_name=db.service_name,
            engine=db.engine,
            cluster_id=db.id,
            name="mydatabase")
        ```

        ## Import

        OVHcloud Managed database clusters databases can be imported using the `service_name`, `engine`, `cluster_id` and `id` of the database, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/databaseInstance:DatabaseInstance my_database service_name/engine/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseInstanceArgs.__new__(DatabaseInstanceArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            if engine is None and not opts.urn:
                raise TypeError("Missing required property 'engine'")
            __props__.__dict__["engine"] = engine
            __props__.__dict__["name"] = name
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["default"] = None
        super(DatabaseInstance, __self__).__init__(
            'ovh:CloudProjectDatabase/databaseInstance:DatabaseInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            default: Optional[pulumi.Input[builtins.bool]] = None,
            engine: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'DatabaseInstance':
        """
        Get an existing DatabaseInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.bool] default: Defines if the database has been created by default.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        :param pulumi.Input[builtins.str] name: Name of the database.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseInstanceState.__new__(_DatabaseInstanceState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["default"] = default
        __props__.__dict__["engine"] = engine
        __props__.__dict__["name"] = name
        __props__.__dict__["service_name"] = service_name
        return DatabaseInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def default(self) -> pulumi.Output[builtins.bool]:
        """
        Defines if the database has been created by default.
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Output[builtins.str]:
        """
        The engine of the database cluster you want to add. You can find the complete list of available engine in the [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the database.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCloudDirectorBackupCurrentStateResult',
    'GetCloudDirectorBackupCurrentStateOfferResult',
    'GetCloudDirectorBackupCurrentTaskResult',
    'GetCloudDirectorBackupIamResult',
    'GetCloudDirectorBackupTargetSpecResult',
    'GetCloudDirectorBackupTargetSpecOfferResult',
    'GetCloudDirectorOrganizationCurrentStateResult',
    'GetCloudDirectorOrganizationCurrentTaskResult',
    'GetCloudDirectorOrganizationIamResult',
    'GetCloudDirectorOrganizationTargetSpecResult',
]

@pulumi.output_type
class GetCloudDirectorBackupCurrentStateResult(dict):
    def __init__(__self__, *,
                 az_name: builtins.str,
                 offers: Sequence['outputs.GetCloudDirectorBackupCurrentStateOfferResult']):
        """
        :param builtins.str az_name: Availability zone of VMware Cloud Director organization backup
        :param Sequence['GetCloudDirectorBackupCurrentStateOfferArgs'] offers: List of your VMware Cloud Director organization backup offers
        """
        pulumi.set(__self__, "az_name", az_name)
        pulumi.set(__self__, "offers", offers)

    @property
    @pulumi.getter(name="azName")
    def az_name(self) -> builtins.str:
        """
        Availability zone of VMware Cloud Director organization backup
        """
        return pulumi.get(self, "az_name")

    @property
    @pulumi.getter
    def offers(self) -> Sequence['outputs.GetCloudDirectorBackupCurrentStateOfferResult']:
        """
        List of your VMware Cloud Director organization backup offers
        """
        return pulumi.get(self, "offers")


@pulumi.output_type
class GetCloudDirectorBackupCurrentStateOfferResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 protection_primary_region: builtins.str,
                 protection_replicated_region: builtins.str,
                 quota_in_tb: builtins.float,
                 status: builtins.str,
                 used_space_in_gb: builtins.float):
        """
        :param builtins.str name: Backup service offer type (BRONZE|SILVER|GOLD)
        :param builtins.str protection_primary_region: Backup repository primary region
        :param builtins.str protection_replicated_region: Backup repository replicated region
        :param builtins.float quota_in_tb: Backup repository quota in TB
        :param builtins.str status: Backup offer status
        :param builtins.float used_space_in_gb: Backup repository used space in GB
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "protection_primary_region", protection_primary_region)
        pulumi.set(__self__, "protection_replicated_region", protection_replicated_region)
        pulumi.set(__self__, "quota_in_tb", quota_in_tb)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "used_space_in_gb", used_space_in_gb)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Backup service offer type (BRONZE|SILVER|GOLD)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="protectionPrimaryRegion")
    def protection_primary_region(self) -> builtins.str:
        """
        Backup repository primary region
        """
        return pulumi.get(self, "protection_primary_region")

    @property
    @pulumi.getter(name="protectionReplicatedRegion")
    def protection_replicated_region(self) -> builtins.str:
        """
        Backup repository replicated region
        """
        return pulumi.get(self, "protection_replicated_region")

    @property
    @pulumi.getter(name="quotaInTb")
    def quota_in_tb(self) -> builtins.float:
        """
        Backup repository quota in TB
        """
        return pulumi.get(self, "quota_in_tb")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Backup offer status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="usedSpaceInGb")
    def used_space_in_gb(self) -> builtins.float:
        """
        Backup repository used space in GB
        """
        return pulumi.get(self, "used_space_in_gb")


@pulumi.output_type
class GetCloudDirectorBackupCurrentTaskResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 link: builtins.str,
                 status: builtins.str,
                 type: builtins.str):
        """
        :param builtins.str id: Identifier of the current task
        :param builtins.str link: Link to the task details
        :param builtins.str status: Current global status of the current task
        :param builtins.str type: Type of the current task
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "link", link)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Identifier of the current task
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def link(self) -> builtins.str:
        """
        Link to the task details
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Current global status of the current task
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the current task
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetCloudDirectorBackupIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetCloudDirectorBackupTargetSpecResult(dict):
    def __init__(__self__, *,
                 offers: Sequence['outputs.GetCloudDirectorBackupTargetSpecOfferResult']):
        """
        :param Sequence['GetCloudDirectorBackupTargetSpecOfferArgs'] offers: List of your VMware Cloud Director backup offers
        """
        pulumi.set(__self__, "offers", offers)

    @property
    @pulumi.getter
    def offers(self) -> Sequence['outputs.GetCloudDirectorBackupTargetSpecOfferResult']:
        """
        List of your VMware Cloud Director backup offers
        """
        return pulumi.get(self, "offers")


@pulumi.output_type
class GetCloudDirectorBackupTargetSpecOfferResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 quota_in_tb: builtins.float):
        """
        :param builtins.str name: Backup service offer type (BRONZE|SILVER|GOLD)
        :param builtins.float quota_in_tb: Backup repository quota in TB
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "quota_in_tb", quota_in_tb)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Backup service offer type (BRONZE|SILVER|GOLD)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="quotaInTb")
    def quota_in_tb(self) -> builtins.float:
        """
        Backup repository quota in TB
        """
        return pulumi.get(self, "quota_in_tb")


@pulumi.output_type
class GetCloudDirectorOrganizationCurrentStateResult(dict):
    def __init__(__self__, *,
                 api_url: builtins.str,
                 billing_type: builtins.str,
                 description: builtins.str,
                 full_name: builtins.str,
                 name: builtins.str,
                 region: builtins.str,
                 spla: builtins.bool,
                 web_interface_url: builtins.str):
        """
        :param builtins.str api_url: API URL to interact with your VMware Cloud Director organization at OVHcloud
        :param builtins.str billing_type: Billing type of your VMware Cloud Director project
        :param builtins.str description: Description of your VMware Cloud Director organization on OVHcloud
        :param builtins.str full_name: Human readable full name of your VMware Cloud Director organization
        :param builtins.str name: Name of your VMware Cloud Director organization
        :param builtins.str region: Datacenter where your VMware Cloud Director organization is physically located
        :param builtins.bool spla: SPLA licensing state
        :param builtins.str web_interface_url: URL to administrate your VMware Cloud Director organization at OVHcloud
        """
        pulumi.set(__self__, "api_url", api_url)
        pulumi.set(__self__, "billing_type", billing_type)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "full_name", full_name)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "spla", spla)
        pulumi.set(__self__, "web_interface_url", web_interface_url)

    @property
    @pulumi.getter(name="apiUrl")
    def api_url(self) -> builtins.str:
        """
        API URL to interact with your VMware Cloud Director organization at OVHcloud
        """
        return pulumi.get(self, "api_url")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.str:
        """
        Billing type of your VMware Cloud Director project
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of your VMware Cloud Director organization on OVHcloud
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fullName")
    def full_name(self) -> builtins.str:
        """
        Human readable full name of your VMware Cloud Director organization
        """
        return pulumi.get(self, "full_name")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of your VMware Cloud Director organization
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Datacenter where your VMware Cloud Director organization is physically located
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def spla(self) -> builtins.bool:
        """
        SPLA licensing state
        """
        return pulumi.get(self, "spla")

    @property
    @pulumi.getter(name="webInterfaceUrl")
    def web_interface_url(self) -> builtins.str:
        """
        URL to administrate your VMware Cloud Director organization at OVHcloud
        """
        return pulumi.get(self, "web_interface_url")


@pulumi.output_type
class GetCloudDirectorOrganizationCurrentTaskResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 link: builtins.str,
                 status: builtins.str,
                 type: builtins.str):
        """
        :param builtins.str id: Identifier of the current task
        :param builtins.str link: Link to the task details
        :param builtins.str status: Current global status of the current task
        :param builtins.str type: Type of the current task
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "link", link)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Identifier of the current task
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def link(self) -> builtins.str:
        """
        Link to the task details
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Current global status of the current task
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the current task
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetCloudDirectorOrganizationIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetCloudDirectorOrganizationTargetSpecResult(dict):
    def __init__(__self__, *,
                 description: builtins.str,
                 full_name: builtins.str):
        """
        :param builtins.str description: Description of your VMware Cloud Director organization at OVHcloud
        :param builtins.str full_name: Human readable full name of your VMware Cloud Director organization
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "full_name", full_name)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of your VMware Cloud Director organization at OVHcloud
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fullName")
    def full_name(self) -> builtins.str:
        """
        Human readable full name of your VMware Cloud Director organization
        """
        return pulumi.get(self, "full_name")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertingArgs', 'Alerting']

@pulumi.input_type
class AlertingArgs:
    def __init__(__self__, *,
                 delay: pulumi.Input[builtins.float],
                 email: pulumi.Input[builtins.str],
                 monthly_threshold: pulumi.Input[builtins.float],
                 service_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a Alerting resource.
        :param pulumi.Input[builtins.float] delay: Delay between two alerts in seconds
        :param pulumi.Input[builtins.str] email: Email to contact
        :param pulumi.Input[builtins.float] monthly_threshold: Monthly threshold for this alerting in currency
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "delay", delay)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "monthly_threshold", monthly_threshold)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def delay(self) -> pulumi.Input[builtins.float]:
        """
        Delay between two alerts in seconds
        """
        return pulumi.get(self, "delay")

    @delay.setter
    def delay(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "delay", value)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[builtins.str]:
        """
        Email to contact
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="monthlyThreshold")
    def monthly_threshold(self) -> pulumi.Input[builtins.float]:
        """
        Monthly threshold for this alerting in currency
        """
        return pulumi.get(self, "monthly_threshold")

    @monthly_threshold.setter
    def monthly_threshold(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "monthly_threshold", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _AlertingState:
    def __init__(__self__, *,
                 creation_date: Optional[pulumi.Input[builtins.str]] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 formatted_monthly_threshold: Optional[pulumi.Input['AlertingFormattedMonthlyThresholdArgs']] = None,
                 monthly_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Alerting resources.
        :param pulumi.Input[builtins.str] creation_date: Alerting creation date
        :param pulumi.Input[builtins.float] delay: Delay between two alerts in seconds
        :param pulumi.Input[builtins.str] email: Email to contact
        :param pulumi.Input['AlertingFormattedMonthlyThresholdArgs'] formatted_monthly_threshold: Formatted monthly threshold for this alerting
        :param pulumi.Input[builtins.float] monthly_threshold: Monthly threshold for this alerting in currency
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        if creation_date is not None:
            pulumi.set(__self__, "creation_date", creation_date)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if formatted_monthly_threshold is not None:
            pulumi.set(__self__, "formatted_monthly_threshold", formatted_monthly_threshold)
        if monthly_threshold is not None:
            pulumi.set(__self__, "monthly_threshold", monthly_threshold)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alerting creation date
        """
        return pulumi.get(self, "creation_date")

    @creation_date.setter
    def creation_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_date", value)

    @property
    @pulumi.getter
    def delay(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Delay between two alerts in seconds
        """
        return pulumi.get(self, "delay")

    @delay.setter
    def delay(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "delay", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Email to contact
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="formattedMonthlyThreshold")
    def formatted_monthly_threshold(self) -> Optional[pulumi.Input['AlertingFormattedMonthlyThresholdArgs']]:
        """
        Formatted monthly threshold for this alerting
        """
        return pulumi.get(self, "formatted_monthly_threshold")

    @formatted_monthly_threshold.setter
    def formatted_monthly_threshold(self, value: Optional[pulumi.Input['AlertingFormattedMonthlyThresholdArgs']]):
        pulumi.set(self, "formatted_monthly_threshold", value)

    @property
    @pulumi.getter(name="monthlyThreshold")
    def monthly_threshold(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Monthly threshold for this alerting in currency
        """
        return pulumi.get(self, "monthly_threshold")

    @monthly_threshold.setter
    def monthly_threshold(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "monthly_threshold", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:CloudProject/alerting:Alerting")
class Alerting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 monthly_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an alert on a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_alert = ovh.cloud_project.Alerting("my_alert",
            service_name="XXX",
            delay=3600,
            email="aaa.bbb@domain.com",
            monthly_threshold=1000)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.float] delay: Delay between two alerts in seconds
        :param pulumi.Input[builtins.str] email: Email to contact
        :param pulumi.Input[builtins.float] monthly_threshold: Monthly threshold for this alerting in currency
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an alert on a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_alert = ovh.cloud_project.Alerting("my_alert",
            service_name="XXX",
            delay=3600,
            email="aaa.bbb@domain.com",
            monthly_threshold=1000)
        ```

        :param str resource_name: The name of the resource.
        :param AlertingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 monthly_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertingArgs.__new__(AlertingArgs)

            if delay is None and not opts.urn:
                raise TypeError("Missing required property 'delay'")
            __props__.__dict__["delay"] = delay
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            if monthly_threshold is None and not opts.urn:
                raise TypeError("Missing required property 'monthly_threshold'")
            __props__.__dict__["monthly_threshold"] = monthly_threshold
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["creation_date"] = None
            __props__.__dict__["formatted_monthly_threshold"] = None
        super(Alerting, __self__).__init__(
            'ovh:CloudProject/alerting:Alerting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            creation_date: Optional[pulumi.Input[builtins.str]] = None,
            delay: Optional[pulumi.Input[builtins.float]] = None,
            email: Optional[pulumi.Input[builtins.str]] = None,
            formatted_monthly_threshold: Optional[pulumi.Input[Union['AlertingFormattedMonthlyThresholdArgs', 'AlertingFormattedMonthlyThresholdArgsDict']]] = None,
            monthly_threshold: Optional[pulumi.Input[builtins.float]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Alerting':
        """
        Get an existing Alerting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] creation_date: Alerting creation date
        :param pulumi.Input[builtins.float] delay: Delay between two alerts in seconds
        :param pulumi.Input[builtins.str] email: Email to contact
        :param pulumi.Input[Union['AlertingFormattedMonthlyThresholdArgs', 'AlertingFormattedMonthlyThresholdArgsDict']] formatted_monthly_threshold: Formatted monthly threshold for this alerting
        :param pulumi.Input[builtins.float] monthly_threshold: Monthly threshold for this alerting in currency
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertingState.__new__(_AlertingState)

        __props__.__dict__["creation_date"] = creation_date
        __props__.__dict__["delay"] = delay
        __props__.__dict__["email"] = email
        __props__.__dict__["formatted_monthly_threshold"] = formatted_monthly_threshold
        __props__.__dict__["monthly_threshold"] = monthly_threshold
        __props__.__dict__["service_name"] = service_name
        return Alerting(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> pulumi.Output[builtins.str]:
        """
        Alerting creation date
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def delay(self) -> pulumi.Output[builtins.float]:
        """
        Delay between two alerts in seconds
        """
        return pulumi.get(self, "delay")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[builtins.str]:
        """
        Email to contact
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="formattedMonthlyThreshold")
    def formatted_monthly_threshold(self) -> pulumi.Output['outputs.AlertingFormattedMonthlyThreshold']:
        """
        Formatted monthly threshold for this alerting
        """
        return pulumi.get(self, "formatted_monthly_threshold")

    @property
    @pulumi.getter(name="monthlyThreshold")
    def monthly_threshold(self) -> pulumi.Output[builtins.float]:
        """
        Monthly threshold for this alerting in currency
        """
        return pulumi.get(self, "monthly_threshold")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ContainerRegistryUserArgs', 'ContainerRegistryUser']

@pulumi.input_type
class ContainerRegistryUserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[builtins.str],
                 login: pulumi.Input[builtins.str],
                 registry_id: pulumi.Input[builtins.str],
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ContainerRegistryUser resource.
        :param pulumi.Input[builtins.str] email: User email
        :param pulumi.Input[builtins.str] login: Registry name
        :param pulumi.Input[builtins.str] registry_id: Registry ID
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "login", login)
        pulumi.set(__self__, "registry_id", registry_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[builtins.str]:
        """
        User email
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def login(self) -> pulumi.Input[builtins.str]:
        """
        Registry name
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> pulumi.Input[builtins.str]:
        """
        Registry ID
        """
        return pulumi.get(self, "registry_id")

    @registry_id.setter
    def registry_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "registry_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _ContainerRegistryUserState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ContainerRegistryUser resources.
        :param pulumi.Input[builtins.str] email: User email
        :param pulumi.Input[builtins.str] login: Registry name
        :param pulumi.Input[builtins.str] password: (Sensitive) User password
        :param pulumi.Input[builtins.str] registry_id: Registry ID
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] user: User name
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if registry_id is not None:
            pulumi.set(__self__, "registry_id", registry_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if user is not None:
            pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User email
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Registry name
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Sensitive) User password
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Registry ID
        """
        return pulumi.get(self, "registry_id")

    @registry_id.setter
    def registry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "registry_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User name
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user", value)


@pulumi.type_token("ovh:CloudProject/containerRegistryUser:ContainerRegistryUser")
class ContainerRegistryUser(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a user for a container registry associated with a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        registry = ovh.CloudProject.get_container_registry(service_name="XXXXXX",
            registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
        user = ovh.cloud_project.ContainerRegistryUser("user",
            service_name=registry_ovh_cloud_project_containerregistry["serviceName"],
            registry_id=registry_ovh_cloud_project_containerregistry["id"],
            email="foo@bar.com",
            login="foobar")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] email: User email
        :param pulumi.Input[builtins.str] login: Registry name
        :param pulumi.Input[builtins.str] registry_id: Registry ID
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContainerRegistryUserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a user for a container registry associated with a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        registry = ovh.CloudProject.get_container_registry(service_name="XXXXXX",
            registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
        user = ovh.cloud_project.ContainerRegistryUser("user",
            service_name=registry_ovh_cloud_project_containerregistry["serviceName"],
            registry_id=registry_ovh_cloud_project_containerregistry["id"],
            email="foo@bar.com",
            login="foobar")
        ```

        :param str resource_name: The name of the resource.
        :param ContainerRegistryUserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContainerRegistryUserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 login: Optional[pulumi.Input[builtins.str]] = None,
                 registry_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContainerRegistryUserArgs.__new__(ContainerRegistryUserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            if login is None and not opts.urn:
                raise TypeError("Missing required property 'login'")
            __props__.__dict__["login"] = login
            if registry_id is None and not opts.urn:
                raise TypeError("Missing required property 'registry_id'")
            __props__.__dict__["registry_id"] = registry_id
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["password"] = None
            __props__.__dict__["user"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ContainerRegistryUser, __self__).__init__(
            'ovh:CloudProject/containerRegistryUser:ContainerRegistryUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[builtins.str]] = None,
            login: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            registry_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            user: Optional[pulumi.Input[builtins.str]] = None) -> 'ContainerRegistryUser':
        """
        Get an existing ContainerRegistryUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] email: User email
        :param pulumi.Input[builtins.str] login: Registry name
        :param pulumi.Input[builtins.str] password: (Sensitive) User password
        :param pulumi.Input[builtins.str] registry_id: Registry ID
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] user: User name
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContainerRegistryUserState.__new__(_ContainerRegistryUserState)

        __props__.__dict__["email"] = email
        __props__.__dict__["login"] = login
        __props__.__dict__["password"] = password
        __props__.__dict__["registry_id"] = registry_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["user"] = user
        return ContainerRegistryUser(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[builtins.str]:
        """
        User email
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def login(self) -> pulumi.Output[builtins.str]:
        """
        Registry name
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        (Sensitive) User password
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> pulumi.Output[builtins.str]:
        """
        Registry ID
        """
        return pulumi.get(self, "registry_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def user(self) -> pulumi.Output[builtins.str]:
        """
        User name
        """
        return pulumi.get(self, "user")

